@@ -6,5 +6,5 @@ from pyfs_auth.app_access_token import AppAccessToken, app_access_token, refresh
 from pyfs_auth.app_access_token_internal import AppAccessTokenInternal, app_access_token_internal, refresh_app_access_token_internal, final_app_access_token_internal
 from pyfs_auth.tenant_access_token import TenantAccessToken, tenant_access_token, refresh_tenant_access_token, final_tenant_access_token
 from pyfs_auth.tenant_access_token_internal import TenantAccessTokenInternal, tenant_access_token_internal, refresh_tenant_access_token_internal, final_tenant_access_token_internal
-from pyfs_auth.authen import Authen, get_userinfo
-from pyfs_auth.oauth2 import OAuth2, get_access_info, get_userinfo
+from pyfs_auth.authen import Authen, authen_get_userinfo, get_userinfo
+from pyfs_auth.oauth2 import OAuth2, get_access_info, oauth2_get_userinfo
